/*-
# MS WINDOWS-BASED PANEX(tm)
#
#  wpanex.h
#
###
#
#  Copyright (c) 1996 - 2006	David Albert Bagley, bagleyd@tux.org
#
#                   All Rights Reserved
#
#  Permission to use, copy, modify, and distribute this software and
#  its documentation for any purpose and without fee is hereby granted,
#  provided that the above copyright notice appear in all copies and
#  that both that copyright notice and this permission notice appear in
#  supporting documentation, and that the name of the author not be
#  used in advertising or publicity pertaining to distribution of the
#  software without specific, written prior permission.
#
#  This program is distributed in the hope that it will be "useful",
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#
*/

/* Header file for wpanex.c */

#define IDM_GET		100
#define IDM_WRITE	101
#define IDM_EXIT	102
#define IDM_HIDE	103
#define IDM_UNDO	200
#define IDM_REDO	201
#define IDM_CLEAR	202
#define IDM_SOLVE	205
#define IDM_MODE	206
#define IDM_SPEED       210
#define IDM_SLOW        211
#define IDM_SOUND       212
#define IDM_DEC		400
#define IDM_INC		401
#define IDM_ABOUT	500
#define IDM_DESCRIPTION	501
#define IDM_FEATURES	502
#define IDM_REFERENCES	503
